# Zscaler Integration for SaaS Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#introduction)
  * [Implementation Details](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#implementation-details)
  * [Discovery Capabilities](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#discovery-capabilities)
  * [Setting up Zscaler Integration](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#setting-up-zscaler-integration)
  * [Create a New API Role](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#create-a-new-api-role)
  * [Create a New User for the Integration](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#create-a-new-user-for-the-integration)
  * [Create an API Token in Zscaler](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#create-an-api-token-in-zscaler)
  * [Enter the Necessary Credentials in SAP LeanIX](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery#enter-the-necessary-credentials-in-sap-leanix)


Configure the SAP LeanIX-Zscaler integration to automatically discover and manage SaaS applications using Zscaler's ZIA API.
